Estimate parameters for the sample mean, variance, and quantiles
Usage
# S3 method for class 'array'
estimate(x, type = "mean", probs = 0.5, ...)Value
Object of class estimate (see estimate.default).
Estimate parameters for the sample mean, variance, and quantiles
# S3 method for class 'array'
estimate(x, type = "mean", probs = 0.5, ...)Object of class estimate (see estimate.default).