Computes the empirical variance of the influence function, providing a sandwich-type variance estimator.
Arguments
- x
Influence function matrix (observations x parameters), typically obtained from IC.
- ...
Additional arguments (currently not used)
Computes the empirical variance of the influence function, providing a sandwich-type variance estimator.
Influence function matrix (observations x parameters), typically obtained from IC.
Additional arguments (currently not used)