Learn R Programming

lava (version 1.9.3)

c.summary.estimate: Concatenate summary.estimate objects

Description

When all arguments are summary.estimate objects, they are merged into a single summary.estimate object. When some arguments are not summary.estimate objects but are named numeric scalars/vectors, an object of class summary.estimate is returned with an additional extra attribute that contains the provided numeric scalars/vectors. This is useful for bundling auxiliary per-iteration information (e.g., convergence status) alongside an estimate for use with sim.default().

Usage

# S3 method for summary.estimate
c(...)

Arguments

...

summary.estimate objects and/or named numeric values

Examples

Run this code
e1 <- estimate(coef = 1, IC = scale(rnorm(10)), id = 1:10, labels = "a1")
e2 <- estimate(coef = 2, IC = scale(rnorm(10)), id = 1:10, labels = "a2")

# concatenating two summary.estimate objects
c(e1, e2)

# concatenating one summary.estimate object with one numerical variable
ss <- c(summary(e1), niter = 2)
print(ss)
attributes(ss)$extra

Run the code above in your browser using DataLab