Learn R Programming

lava (version 1.9.3)

lava-package: lava: Latent Variable Models

Description

logo

A general implementation of Structural Equation Models with latent variables (MLE, 2SLS, and composite likelihood estimators) with both continuous, censored, and ordinal outcomes (Holst and Budtz-Joergensen (2013) tools:::Rd_expr_doi("10.1007/s00180-012-0344-y")). Mixture latent variable models and non-linear latent variable models (Holst and Budtz-Joergensen (2020) tools:::Rd_expr_doi("10.1093/biostatistics/kxy082")). The package also provides methods for graph exploration (d-separation, back-door criterion), simulation of general non-linear latent variable models, and estimation of influence functions for a broad range of statistical models.

A general implementation of Structural Equation Models wth latent variables (MLE, 2SLS, and composite likelihood estimators) with both continuous, censored, and ordinal outcomes (Holst and Budtz-Joergensen (2013) doi:10.1007/s00180-012-0344-y). Mixture latent variable models and non-linear latent variable models (Holst and Budtz-Joergensen (2020) doi:10.1093/biostatistics/kxy082). The package also provides methods for graph exploration (d-separation, back-door criterion), simulation of general non-linear latent variable models, and estimation of influence functions for a broad range of statistical models.

Arguments

Author

Maintainer: Klaus K. Holst klaus@holst.it

Authors:

Other contributors:

  • Benedikt Sommer [contributor]

  • Brice Ozenne [contributor]

  • Thomas Gerds [contributor]

Klaus K. Holst Maintainer: klaus@holst.it

See Also

Examples

Run this code
lava()

Run the code above in your browser using DataLab