Merge estimate objects
# S3 method for estimate
merge(
x,
y,
...,
id,
paired = FALSE,
labels = NULL,
keep = NULL,
subset = NULL,
regex = FALSE,
sep = FALSE,
drop.ic = FALSE,
ignore.case = FALSE,
sort = FALSE
)Object of class estimate (see estimate.default).
Object of class estimate
Object of class estimate
Additional estimate objects or arguments
Optional cluster variable
If TRUE a paired (matched) analysis is performed
Optional character vector of labels for the merged estimates
Optional character vector of parameter names to keep
Optional character vector of parameter names to subset
If TRUE, keep and subset are treated as regular expressions
Separator used for labeling
If TRUE, drop the influence function from the result
If TRUE, case is ignored in keep/subset matching
if true the returned influence function will be sorted according to the id variables (lexigraphically)
c.estimate()