Computes hypothesis tests, contrasts, and small-sample corrections for
an estimate object. The arguments null, contrast, type, and
var.adj were previously available on estimate.default() and have
been moved here.
# S3 method for estimate
summary(
object,
contrast,
...,
null = 0,
level = 0.95,
type,
var.adj = 0.25,
df,
transform = NULL,
print = NULL
)an estimate object.
(optional) contrast matrix for the final Wald test.
additional arguments passed to contr.
(optional) null hypothesis to test.
level of confidence limits (default 0.95)
type of small-sample correction. Requires the estimate to have
been computed with IC=TRUE (the default).
variance adjustment parameter for small-sample correction.
Requires the estimate to have been computed with IC=TRUE (the default).
degrees of freedom for t-based inference (default: NULL for
Gaussian approximation; when set, confidence intervals and p-values use the
t-distribution with df degrees of freedom)
(optional) function applied to the point estimates and
confidence interval bounds after inference is performed on the original
scale. Useful for variance-stabilizing transformations, e.g., compute CIs
on the atanh (Fisher z) scale and back-transform with tanh.
(optional) custom print function for the resulting
summary.estimate object
estimate.default()